<?php

namespace Drupal\page_not_found_files_reports\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form for page not found files report setting.
 */
class ReportsSettings extends ConfigFormBase {

  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId() {
    return 'pnf_files_reports_settings';
  }

  /**
   * Gets the configuration names that will be editable.
   *
   * @return array
   *   An array of configuration object names that are editable if called in
   *   conjunction with the trait's config() method.
   */
  protected function getEditableConfigNames() {
    return ['pnf_files_reports.settings'];
  }

  /**
   * Form constructor.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   The form structure.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('pnf_files_reports.settings');

    $form['report_link'] = [
      '#type' => 'markup',
      '#markup' => '<a href="/admin/reports/page-not-found-files">Report Link</a>'
    ];
    $form['page_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Page URL'),
      '#description' => 'Enter specific page url to generate report. By Default report genarated with full site urls inside sitemap.xml.',
      '#default_value' => $config->get('page_url')
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * Form validation handler.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('pnf_files_reports.settings');
  }

  /**
   * Form submission handler.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('pnf_files_reports.settings');

    $config->set('page_url', $form_state->getValue('page_url'));

    $config->save();

    parent::submitForm($form, $form_state);
  }

}
